@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- *                                                                              
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *                                                                              
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -34,7 +34,7 @@
 #endif
 
 #include <libxfce4util/libxfce4util.h>
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include <libxfsm/xfsm-splash-engine.h>
 #include <libxfsm/xfsm-util.h>
@@ -45,9 +45,6 @@
 #define BORDER 6
 
 
-static void xfsm_chooser_class_init (XfsmChooserClass *klass);
-static void xfsm_chooser_init (XfsmChooser *chooser);
-static void xfsm_chooser_finalize (GObject *object);
 static void xfsm_chooser_row_activated (GtkTreeView       *treeview,
                                         GtkTreePath       *path,
                                         GtkTreeViewColumn *column,
@@ -66,36 +63,9 @@ enum
 };
 
 
-static GObjectClass *parent_class;
 
+G_DEFINE_TYPE (XfsmChooser, xfsm_chooser, GTK_TYPE_DIALOG)
 
-GType
-xfsm_chooser_get_type (void)
-{
-  static GType chooser_type = 0;
-
-  if (chooser_type == 0)
-    {
-      static const GTypeInfo chooser_info = {
-        sizeof (XfsmChooserClass),
-        NULL,
-        NULL,
-        (GClassInitFunc) xfsm_chooser_class_init,
-        NULL,
-        NULL,
-        sizeof (XfsmChooser),
-        0,
-        (GInstanceInitFunc) xfsm_chooser_init,
-      };
-
-      chooser_type = g_type_register_static (GTK_TYPE_DIALOG,
-                                             "XfsmChooser",
-                                             &chooser_info,
-                                             0);
-    }
-
-  return chooser_type;
-}
 
 
 void
@@ -160,12 +130,6 @@ xfsm_chooser_get_session (const XfsmChooser *chooser)
 static void
 xfsm_chooser_class_init (XfsmChooserClass *klass)
 {
-  GObjectClass *gobject_class;
-
-  gobject_class = G_OBJECT_CLASS (klass);
-  gobject_class->finalize = xfsm_chooser_finalize;
-
-  parent_class = gtk_type_class (gtk_dialog_get_type ());
 }
 
 
@@ -181,19 +145,14 @@ xfsm_chooser_init (XfsmChooser *chooser)
   GtkWidget *dbox;
 
   dbox = GTK_DIALOG (chooser)->vbox;
-  
+
   gtk_dialog_set_has_separator (GTK_DIALOG (chooser), FALSE);
   g_signal_connect_after (G_OBJECT (chooser), "realize",
                           G_CALLBACK (xfsm_chooser_realized), chooser);
 
-  /* allocate tooltips */
-  chooser->tooltips = gtk_tooltips_new ();
-  g_object_ref (G_OBJECT (chooser->tooltips));
-  gtk_object_sink (GTK_OBJECT (chooser->tooltips));
-
   /* scrolled window */
   swin = gtk_scrolled_window_new (NULL, NULL);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (swin), 
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (swin),
                                   GTK_POLICY_NEVER,
                                   GTK_POLICY_AUTOMATIC);
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (swin),
@@ -209,11 +168,11 @@ xfsm_chooser_init (XfsmChooser *chooser)
                               G_TYPE_INT);
   chooser->tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL(model));
   g_object_unref (G_OBJECT (model));
-  gtk_tooltips_set_tip (chooser->tooltips, chooser->tree,
-                        _("Choose the session you want to restore. "
-                          "You can simply double-click the session "
-                          "name to restore it."),
-                        NULL);
+  gtk_widget_set_tooltip_text (chooser->tree,
+                               _("Choose the session you want to restore. "
+                                 "You can simply double-click the session "
+                                 "name to restore it."));
+
   gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (chooser->tree), FALSE);
   column = gtk_tree_view_column_new ();
   renderer = gtk_cell_renderer_pixbuf_new ();
@@ -236,38 +195,23 @@ xfsm_chooser_init (XfsmChooser *chooser)
   gtk_widget_show (chooser->tree);
 
   /* "Logout" button */
-  button = xfce_create_mixed_button (GTK_STOCK_QUIT, _("Log out"));
-  gtk_tooltips_set_tip (chooser->tooltips, button,
-                        _("Cancel the login attempt and return to "
-                          "the login screen."),
-                        NULL);
+  button = xfce_gtk_button_new_mixed (GTK_STOCK_QUIT, _("Log out"));
+  gtk_widget_set_tooltip_text (button,
+                               _("Cancel the login attempt and return to "
+                                 "the login screen."));
   gtk_dialog_add_action_widget (GTK_DIALOG (chooser), button,
                                 GTK_RESPONSE_CANCEL);
   gtk_widget_show (button);
 
   /* "New" button */
-  button = xfce_create_mixed_button (GTK_STOCK_NEW, _("New session"));
-  gtk_tooltips_set_tip (chooser->tooltips, button,
-                        _("Create a new session."),
-                        NULL);
+  button = xfce_gtk_button_new_mixed (GTK_STOCK_NEW, _("New session"));
+  gtk_widget_set_tooltip_text (button, _("Create a new session."));
   gtk_dialog_add_action_widget (GTK_DIALOG (chooser), button,
                                 XFSM_RESPONSE_NEW);
   gtk_widget_show (button);
 }
 
 
-static void
-xfsm_chooser_finalize (GObject *object)
-{
-  XfsmChooser *chooser;
-
-  chooser = XFSM_CHOOSER (object);
-  g_object_unref (chooser->tooltips);
-
-  G_OBJECT_CLASS (parent_class)->finalize (object);
-}
-
-
 static void
 xfsm_chooser_row_activated (GtkTreeView       *treeview,
                             GtkTreePath       *path,
